<template>
  <div class="bbsl-common-page">
    <div class="bbsl-btn-content" ref="btnPanel">
      <el-button icon="el-icon-plus" type="primary" @click="handleAdd">添加关联</el-button>
      <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
        <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"
                   style="margin-left: 10px">删除
        </el-button>
      </el-popconfirm>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <!-- <div class="bbsl-btn-content" ref="btnPanel"></div> -->
      <el-table border size="mini" :data="tableData" :height="tableMaxHeight" :style="{width: '100%'}"
                :cell-style="{'text-align': 'center'}" :header-cell-style="{'text-align': 'center'}"
                @row-dblclick="handleDbClick" @selection-change="handleSelectionChange">
        <el-table-column type="selection" width="55"></el-table-column>
        <el-table-column fixed type="index" width="55" label="序号"></el-table-column>
        <el-table-column min-width="130" fixed sortable prop="contractCode" label="合同编码" show-overflow-tooltip>
        </el-table-column>
        <el-table-column fixed min-width="150" sortable prop="contractName" label="合同名称" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="80" sortable prop="personLiable" label="责任人" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="110" sortable prop="signDate" label="合同签订时间" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="100" prop="contractType" label="合同类型" show-overflow-tooltip>
          <template #default="scope">
            <div>
              {{
              scope.row.contractType == 1
              ? '采购合同'
              : scope.row.contractType == 2
              ? '建设合同'
              : '运维合同'
              }}
            </div>
          </template>
        </el-table-column>
        <el-table-column min-width="110" sortable prop="startDate" label="合同开始时间" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="110" sortable prop="endDate" label="合同结束时间" show-overflow-tooltip>
        </el-table-column>
        <el-table-column min-width="90" sortable prop="contractStatus" label="合同状态" show-overflow-tooltip>
          <template #default="scope">
            <div>
              {{ scope.row.contractStatus == 1 ? '进行中' : '已完成' }}
            </div>
          </template>
        </el-table-column>
        <el-table-column min-width="120" sortable prop="companyName" label="供应商" show-overflow-tooltip>
        </el-table-column>
      </el-table>
      <el-pagination align="right" background ref="paginationPanel" @size-change="handleSizeChange"
                     @current-change="handleCurrentChange" :current-page="queryParam.pageBean.page"
                     :page-sizes="[20, 30, 40, 50]" :page-size="queryParam.pageBean.pageSize"
                     layout="total, sizes, prev, pager, next, jumper" :total="total"></el-pagination>
    </div>
    <relatedDeviceDialog ref="formModal"></relatedDeviceDialog>
  </div>
</template>

<script>
import {TableMixin} from '@/mixins/tableMixin'
import VideoFacilities from '@/api/device/VideoFacilities.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import relatedDeviceDialog from './relatedDeviceDialog'

export default {
  name: 'relatedDevice',
  components: {
    relatedDeviceDialog
  },
  mixins: [TableMixin],
  props: {
    parameter: {
      type: Object,
      default: function() {
        return
      }
    }
  },
  data() {
    return {
      url: {
        delete: '/device/relation/contract/'
      }, // 删除关联信息
      tableData: [],
      multipleSelection: [],
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'deviceId',
          relation: 'AND',
          value: this.parameter.code
        }
      ]
    }
  },
  created() {
  },
  mounted() {
  },
  methods: {
    handleAdd() {
      this.$refs.formModal.add(this.parameter)
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      VideoFacilities.getDeviceList(this.queryParam, (res) => {
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}

.title-box {
  display: flex;
  padding: 10px 0;

  .title {
    font-weight: 600;
  }

  .bule {
    color: #1289fd;
  }
}

::v-deep .el-table {
  height: 100% !important;
}

::v-deep .bbsl-table-content {
  box-shadow: 0px 0px 0 0;
  margin-top: 0px;
  padding: 0px;
}
</style>
